import { z } from 'zod';
import { UserId } from '../user/types';
import { BlogId } from './id.types';
import { blogAdminsTraitParser } from './parsers';
import { Split } from '../split/types';
export interface BlogIdTrait {
    id: BlogId;
}
export interface BlogAdminsTrait {
    admins: UserId[];
}
export type BlogOwnedTrait = z.infer<typeof blogAdminsTraitParser>;
export interface BlogCore extends BlogAdminsTrait, Split {
    aboutArtist: string;
    artist: string;
    artistPicSmall?: string | null;
    artistPicURL?: string | null;
    beneficiaryAccepted?: boolean | null;
    communityPage?: boolean | null;
    coverPicSmall?: string | null;
    coverPicURL?: string | null;
    coverPicURLSmall?: string | null;
    coverResolutions: Record<string, string | null>;
    coverSmall?: string | null;
    curatorAlpha?: boolean | null;
    createdAllowReminder?: boolean | null;
    customlink?: string | null;
    description?: string | null;
    emailNewSubscribers?: boolean | null;
    emailSettings: Record<string, boolean | null>;
    featuredArtists: string[];
    founder?: boolean | null;
    freetier: boolean;
    frequency?: string | null;
    launchDraft?: string | null;
    launched: boolean;
    linkTitles: string[];
    links: string[];
    paypal?: boolean | null;
    'paypal_plan_2.5'?: string | null;
    paypal_plan_5?: string | null;
    paypal_plan_10?: string | null;
    paypal_product_id?: string | null;
    posts: string[];
    price?: number | null;
    profileResolutions?: object | null;
    reminderLaunchSent?: boolean | null;
    reverseTitle?: boolean | null;
    scheduled?: boolean | null;
    show?: string | null;
    stripeProductID?: string | null;
    subscribers: string[];
    tipButton?: boolean | null;
    title: string;
    verified: boolean;
}
export interface BlogDerived {
    artistLowercase: string;
    artistTokens: string[];
    titleLowercase: string;
}
export interface BlogWithTime {
    created: Date;
}
export type Blog = BlogCore & BlogIdTrait;
