"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.routingStrategyIsomorphism = void 0;
const parsers_1 = require("./parsers");
const constants_1 = require("./constants");
const function_1 = require("../../utils/function");
const array_1 = require("../../utils/array");
const general_1 = require("../../utils/general");
const KEY_KEY = 'key';
exports.routingStrategyIsomorphism = {
    to: (s) => {
        const kvs = s.split(constants_1.ROUTING_STRATEGY_SERIALIZED_SEPARATOR);
        (0, general_1.assertEqual)(kvs.length, new Set(kvs.map((kv) => kv[0])).size, 'panic! duplicate keys');
        const pairs = kvs
            .map((kv) => kv.split(constants_1.ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR))
            .map((0, function_1.ary1)((0, array_1.assertExactLength)(2, `panic! Invalid routing strategy serialized: ${s}, extra "${constants_1.ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}" symbol?`)));
        const [keyPairs, nonKeyPairs] = (0, array_1.partition)(pairs, ([k]) => k === KEY_KEY);
        const keyPair = (0, array_1.getOnlyOne)(keyPairs);
        return parsers_1.routingStrategyParser.parse({
            [keyPair[0]]: keyPair[1],
            ...(keyPair[1] === constants_1.ROUTING_STRATEGY_KEY_FANOUT
                ? {}
                : { params: parsers_1.routingStrategyThresholdQueryParamsParser.parse(Object.fromEntries(nonKeyPairs)) }),
        });
    },
    from: (r) => {
        return Object.entries({
            key: r['key'],
            ...(r.key === constants_1.ROUTING_STRATEGY_KEY_FANOUT || r.key === constants_1.ROUTING_STRATEGY_KEY_ACTIVATION_THRESHOLD ? {} : r.params),
        })
            .map(([k, v]) => `${k}${constants_1.ROUTING_STRATEGY_SERIALIZED_KV_SEPARATOR}${v}`)
            .join(constants_1.ROUTING_STRATEGY_SERIALIZED_SEPARATOR);
    },
};
