import { z } from 'zod';
import { routeContextBindBodyParser, routeContextBodyParser, routeContextDetailsResultParser, routeContextInitResultParser, routeContextParamsParser, routeContextQueryParser, routePacketQueryParser } from './parsers';
import { GraphEdgeUnit } from '../../graph/types';
import { RoutableEdgeType, RoutableNodeType } from '../../graph/routing/types';
export type PayinRouteQuery = z.input<typeof routePacketQueryParser>;
export type PayinRouteQueryTransformed = z.output<typeof routePacketQueryParser>;
export type PayinRouteResult = {
    endpoints: Array<{
        amt: number;
        packets: Array<{
            amt: number;
            payee: string;
            path: Array<{
                src: string;
                dst: string;
                edgeAmt: number;
                edgeUnit: GraphEdgeUnit;
                transferredAmt: number;
            }>;
        }>;
    }>;
    traces: {
        nodes: {
            uuid: string;
            type: RoutableNodeType;
        }[];
        edges: {
            type: RoutableEdgeType;
            src: string;
            dst: string;
        }[];
    }[];
};
export type PayinContextQuery = z.input<typeof routeContextQueryParser>;
export type PayinContextQueryTransformed = z.output<typeof routeContextQueryParser>;
export type PayinContextParams = z.input<typeof routeContextParamsParser>;
export type PayinContextParamsTransformed = z.output<typeof routeContextParamsParser>;
export type PayinContextDetailsResult = z.infer<typeof routeContextDetailsResultParser>;
export type PayinContextBody = z.input<typeof routeContextBodyParser>;
export type PayinContextBodyTransformed = z.output<typeof routeContextBodyParser>;
export type PayinContextInitResult = z.infer<typeof routeContextInitResultParser>;
export type PayinContextBindBody = z.input<typeof routeContextBindBodyParser>;
export type PayinContextBindBodyTransformed = z.output<typeof routeContextBindBodyParser>;
