"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paymentMethodListLimitParser = exports.paymentMethodLimitParser = exports.paymentMethodCompositeKeyParamsParser = exports.paypalPaymentMethodOriginIdParser = exports.stripePamentMethodOriginIdParser = void 0;
const zod_1 = require("zod");
const routes_constant_1 = require("./routes.constant");
const parsers_1 = require("../stripe/parsers");
const queryParams_1 = require("../common/parsers/queryParams");
exports.stripePamentMethodOriginIdParser = zod_1.z.object({
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: parsers_1.stripePaymentMethodIdParser,
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: zod_1.z.literal('stripe'),
});
exports.paypalPaymentMethodOriginIdParser = zod_1.z.object({
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: zod_1.z.string(),
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: zod_1.z.literal('paypal'),
});
// TODO may become different for payin/payout if origins become different
exports.paymentMethodCompositeKeyParamsParser = zod_1.z.discriminatedUnion(routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME, [
    exports.stripePamentMethodOriginIdParser,
    exports.paypalPaymentMethodOriginIdParser,
]);
exports.paymentMethodLimitParser = queryParams_1.queryLimitParser.superRefine((a, ctx) => {
    if (a < 0) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.too_small,
            message: 'Limit must be positive',
            minimum: 0,
            inclusive: true,
            type: 'number',
        });
    }
    const MAX = 100; /*stripe max, don't expose stripe related stuff here tho*/
    if (a > MAX) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.too_big,
            message: `Limit must be less than ${MAX}`,
            maximum: MAX,
            inclusive: true,
            type: 'number',
        });
    }
    return a;
});
exports.paymentMethodListLimitParser = (0, queryParams_1.makeLimitParser)(exports.paymentMethodLimitParser);
