import z from 'zod';
import { UserId } from '../user/types';
import { PayoutMethodOriginType } from '../payoutMethod/types';
import { Currency } from '../currencies/types';
import { payoutBodyParser, payoutParamsParser, payoutResultParser, payoutRetryBodyParser } from './parsers';
import { PAYOUT_QUEUE_LINE_GRANULAR_ORIGIN_TYPES, PAYOUT_QUEUE_NON_LINE_GRANULAR_ORIGIN_TYPES, PAYOUT_QUEUE_STATUSES } from './constants';
export declare enum PayoutBatchKeyBrand {
    _ = ""
}
export type PayoutBatchKey = string & PayoutBatchKeyBrand;
export type PayoutBatchItemCompositeKeySerialized<T extends PayoutMethodOriginType = PayoutMethodOriginType> = `${UserId}:${T}:${Currency}`;
export type PayoutMethodOriginTypeLineGranular = PayoutMethodOriginType & (typeof PAYOUT_QUEUE_LINE_GRANULAR_ORIGIN_TYPES)[number];
export type PayoutMethodOriginTypeNonLineGranular = PayoutMethodOriginType & (typeof PAYOUT_QUEUE_NON_LINE_GRANULAR_ORIGIN_TYPES)[number];
export type PayoutMethodOriginTypeLineNonGranular = Exclude<PayoutMethodOriginType, PayoutMethodOriginTypeLineGranular>;
export type PayoutBatchItemLineableCompositeKeySerialized = PayoutBatchItemCompositeKeySerialized<PayoutMethodOriginTypeLineGranular>;
export type PayoutBatchItemNonLineableCompositeKeySerialized = PayoutBatchItemCompositeKeySerialized<PayoutMethodOriginTypeLineNonGranular>;
export interface PayoutBatchLineItemCompositeKey<T extends PayoutMethodOriginType = PayoutMethodOriginType> {
    userId: UserId;
    originType: T;
    currency: Currency;
}
export type PayoutBody = z.input<typeof payoutBodyParser>;
export type PayoutBodyTransformed = z.output<typeof payoutBodyParser>;
export type PayoutRetryBody = z.input<typeof payoutRetryBodyParser>;
export type PayoutRetryBodyTransformed = z.output<typeof payoutRetryBodyParser>;
export type PayoutParams = z.input<typeof payoutParamsParser>;
export type PayoutParamsTransformed = z.output<typeof payoutParamsParser>;
export type PayoutResult = z.infer<typeof payoutResultParser>;
export type AuthorPayoutArgs<OriginType extends PayoutMethodOriginType = PayoutMethodOriginType> = Partial<Record<PayoutBatchItemCompositeKeySerialized<OriginType>, number>>;
export type PayoutQueueItemStatus = (typeof PAYOUT_QUEUE_STATUSES)[number];
