import { ROUTE_IDS } from './constants';
import type { ResetPasswordRequest } from './auth/local/resetPassword/types';
import type { LocalSignupRequest } from './auth/local/signup/types';
import { PayinContextBody, PayinContextParams, PayinContextQuery, PayinContextDetailsResult, PayinRouteQuery, PayinRouteResult, PayinContextInitResult, PayinContextBindBody } from './payin/route/types';
import { BlogCreateBody, BlogDeleteParams, BlogGetOneParams, BlogGetOneResult, BlogListQuery, BlogListResult, BlogUpdateBody, BlogUpdateParams } from './blog/api.types';
import { CreateBlogResponse } from './blog/parsers';
import { CollectiveCreateBody, CollectiveDeleteParams, CollectiveGetOneParams, CollectiveGetOneResult, CollectiveListQuery, CollectiveListResult, CollectiveUpdateBody, CollectiveUpdateParams } from './collective/api.types';
import { CreateCollectiveResponse } from './collective/parsers';
import { LocalSigninRequest } from './auth/local/signin/types';
import { MixspaceCreateBody, MixspaceCreateResult, MixspaceDeleteParams, MixspaceGetOneParams, MixspaceGetOneResult, MixspaceListQuery, MixspaceListResult, MixspaceUpdateBody, MixspaceUpdateParams } from './mixspace/api.types';
import { PayinMethodDeleteParams, PayinMethodListQuery, PayinMethodListResult, PayinMethodUpsertParams, PayinMethodUpsertResult } from './payinMethod/api.types';
import { UserId } from './user/types';
import { PayoutMethodListQuery, PayoutMethodListResult, PayoutMethodStripeAuthorizeResult, PayoutMethodStripeTokenBody } from './payoutMethod/types';
import { AuthUserGetOneParams, AuthUserGetOneResult, AuthUserListQuery, AuthUserListResult } from './auth/user/api.types';
import { SubscriptionCreateApiBody, SubscriptionCreateApiResponse, SubscriptionDeleteApiParams, SubscriptionListApiQuery, SubscriptionListApiResponse, SubscriptionUpdateApiBody, SubscriptionUpdateApiParams, SubscriptionUpdateApiResponse } from './subscription/types';
import { ApiTip, TipCreateApiBody, TipCreateApiResponse, TipFetchParams, TipFetchQuery, TipListApiQuery, TipListApiResponse } from './tip/types';
import { ChannelAutocompleteQuery, ChannelAutocompleteResult } from './search/channels/autocomplete/types';
import { PayoutBody, PayoutParams, PayoutResult, PayoutRetryBody } from './payout/types';
import { PayoutQueueQuery, PayoutQueueResult, PayoutQueueStatusResult } from './payout/queue/types';
import { RerunImpossiblePaymentIntentParams } from './payin/types';
import { UserBooksQuery, UserBooksReportResponseSerialized, UserBooksUsersResponse, UsersBooksQuery, UsersBooksReportResponseSerialized } from './books/report/types';
import { ImpossiblePaymentIntentsQuery, ImpossiblePaymentIntentsResult } from './payin/stripe/impossiblePaymentIntent/types';
import { UserBooksMovementConversionProviderBody, UserBooksMovementConversionProviderParams } from './books/movements/conversion/provider/types';
import { AudienceIntentDeclareResult, AudienceIntentParams, AudienceIntentRevokeResult } from './audience/intent/types';
export type RouteId = (typeof ROUTE_IDS)[number];
interface ApiType<P, Q, B, R> {
    params?: P;
    query?: Q;
    body?: B;
    result: R;
}
interface BodyType<B, R> extends ApiType<unknown, unknown, B, R> {
    body: B;
}
interface ParamsType<P, R> extends ApiType<P, unknown, unknown, R> {
    params: P;
}
interface QueryType<Q, R> extends ApiType<unknown, Q, unknown, R> {
    query: Q;
}
type NoopType = ApiType<unknown, unknown, unknown, null>;
type ResponseType<R> = ApiType<unknown, unknown, unknown, R>;
export interface ApiTypes {
    resetPassword: BodyType<ResetPasswordRequest, null>;
    localSignup: BodyType<LocalSignupRequest, UserId>;
    localSignin: BodyType<LocalSigninRequest, UserId>;
    signout: NoopType;
    googleAuthInit: NoopType;
    createBlog: BodyType<BlogCreateBody, CreateBlogResponse>;
    fetchBlog: ParamsType<BlogGetOneParams, BlogGetOneResult>;
    fetchBlogs: QueryType<BlogListQuery, BlogListResult>;
    updateBlog: ApiType<BlogUpdateParams, unknown, BlogUpdateBody, null>;
    deleteBlog: ParamsType<BlogDeleteParams, null>;
    createCollective: BodyType<CollectiveCreateBody, CreateCollectiveResponse>;
    fetchCollective: ParamsType<CollectiveGetOneParams, CollectiveGetOneResult>;
    fetchCollectives: QueryType<CollectiveListQuery, CollectiveListResult>;
    updateCollective: ApiType<CollectiveUpdateParams, unknown, CollectiveUpdateBody, null>;
    deleteCollective: ParamsType<CollectiveDeleteParams, null>;
    fetchAuthUser: ParamsType<AuthUserGetOneParams, AuthUserGetOneResult>;
    fetchAuthUsers: QueryType<AuthUserListQuery, AuthUserListResult>;
    payinRoute: QueryType<PayinRouteQuery, PayinRouteResult>;
    payinRouteContextDetails: ApiType<PayinContextParams, PayinContextQuery, unknown, PayinContextDetailsResult>;
    payinRouteContextInit: BodyType<PayinContextBody, PayinContextInitResult>;
    payinRouteContextBind: ApiType<PayinContextParams, unknown, PayinContextBindBody, null>;
    payinRouteContextActivate: ParamsType<PayinContextParams, null>;
    createMixspace: BodyType<MixspaceCreateBody, MixspaceCreateResult>;
    updateMixspace: ApiType<MixspaceUpdateParams, unknown, MixspaceUpdateBody, null>;
    fetchMixspace: ParamsType<MixspaceGetOneParams, MixspaceGetOneResult>;
    fetchMixspaces: QueryType<MixspaceListQuery, MixspaceListResult>;
    deleteMixspace: ParamsType<MixspaceDeleteParams, null>;
    upsertPayinMethod: ParamsType<PayinMethodUpsertParams, PayinMethodUpsertResult>;
    fetchPayinMethods: QueryType<PayinMethodListQuery, PayinMethodListResult>;
    deletePayinMethod: ParamsType<PayinMethodDeleteParams, null>;
    fetchPayoutMethods: QueryType<PayoutMethodListQuery, PayoutMethodListResult>;
    payoutMethodStripeAuthorize: ApiType<unknown, unknown, unknown, PayoutMethodStripeAuthorizeResult>;
    payoutMethodStripeToken: BodyType<PayoutMethodStripeTokenBody, null>;
    fetchSubscriptions: QueryType<SubscriptionListApiQuery, SubscriptionListApiResponse>;
    createSubscription: BodyType<SubscriptionCreateApiBody, SubscriptionCreateApiResponse>;
    updateSubscription: ApiType<SubscriptionUpdateApiParams, unknown, SubscriptionUpdateApiBody, SubscriptionUpdateApiResponse>;
    deleteSubscription: ParamsType<SubscriptionDeleteApiParams, unknown>;
    fetchTips: QueryType<TipListApiQuery, TipListApiResponse>;
    createTip: BodyType<TipCreateApiBody, TipCreateApiResponse>;
    fetchTip: ApiType<TipFetchParams, TipFetchQuery, unknown, ApiTip>;
    channelAutocomplete: QueryType<ChannelAutocompleteQuery, ChannelAutocompleteResult>;
    runPayout: BodyType<PayoutBody, PayoutResult> & ParamsType<PayoutParams, PayoutResult>;
    retryPayout: BodyType<PayoutRetryBody, PayoutResult> & ParamsType<PayoutParams, PayoutResult>;
    cancelPayout: ParamsType<PayoutParams, null>;
    payoutBatchStatus: ParamsType<PayoutParams, PayoutQueueStatusResult>;
    listPayoutQueue: QueryType<PayoutQueueQuery, PayoutQueueResult>;
    listImpossiblePaymentIntents: QueryType<ImpossiblePaymentIntentsQuery, ImpossiblePaymentIntentsResult>;
    listImpossiblePaymentIntentsCsv: QueryType<ImpossiblePaymentIntentsQuery, string>;
    rerunImpossiblePaymentIntent: ParamsType<RerunImpossiblePaymentIntentParams, null>;
    userBooksReport: QueryType<UsersBooksQuery, UsersBooksReportResponseSerialized>;
    userBooksReportCsv: QueryType<UsersBooksQuery, string>;
    userBooksDetailsReport: QueryType<UserBooksQuery, UserBooksReportResponseSerialized>;
    userBooksDetailsReportCsv: QueryType<UserBooksQuery, string>;
    userBooksUsers: ResponseType<UserBooksUsersResponse>;
    userBooksProviderConversion: BodyType<UserBooksMovementConversionProviderBody, unknown> & ParamsType<UserBooksMovementConversionProviderParams, unknown>;
    declareAudienceIntent: ParamsType<AudienceIntentParams, AudienceIntentDeclareResult>;
    revokeAudienceIntent: ParamsType<AudienceIntentParams, AudienceIntentRevokeResult>;
}
export {};
