import { z } from 'zod';
import { makePositiveIntegerQueryParser } from '../common/parsers/queryParams';

export const booleanQueryParser = z
  .enum(['true', 'false', ''])
  .optional()
  .transform((v) => (v === 'true' ? true : v === 'false' ? false : undefined));

export const timestampParser = z.number().int();
export const timestampQueryParser = makePositiveIntegerQueryParser('Timestamp');

export const ISO_DATE_REGEX =
  /(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))/;
export const isoDateTimeStringParser = z.string().regex(ISO_DATE_REGEX);
