import z from 'zod';
import { queryOffsetLimitParser } from '../common/parsers/queryParams';
import { currencyAmountParser, currencyParser } from '../currencies/parsers';
import { chargeRoutingContextIdParser } from './route/parsers';
import { payinCompositeKeyIsomorphism } from './isomorphism';
import { PayinCompositeIdSerialized } from './types';
import { payinApiDstCompositeParser, payinApiSrcCompositeParser } from './parsers.common';

export const payinApiSrcDstCompositeParserOptional = z.object({
  src: payinApiSrcCompositeParser.optional(),
  dst: payinApiDstCompositeParser.optional(),
});

export const payinApiSrcDstCompositeParser = z.object({
  src: payinApiSrcCompositeParser,
  dst: payinApiDstCompositeParser,
});

export const payinListQueryParser = queryOffsetLimitParser.merge(payinApiSrcDstCompositeParserOptional);
export const payinAmountParser = currencyAmountParser;
export const payinUnitParser = currencyParser;
export const payinApiAmountParser = z.object({
  amt: payinAmountParser,
});
export const payinAmountUnitParser = z
  .object({
    unit: payinUnitParser,
  })
  .merge(payinApiAmountParser);

export const payinContextParser = z.object({
  contextId: chargeRoutingContextIdParser.optional(),
});

export const payinSerializedKeyParser = z
  .string()
  .transform((s) =>
    payinCompositeKeyIsomorphism.to(payinCompositeKeyIsomorphism.from(s as PayinCompositeIdSerialized))
  );
