import { z } from 'zod';
import { PayinMethodOriginId } from './types';
import { stripePaymentMethodFlatParser, stripePaymentMethodIdParser } from '../stripe/parsers';
import { PAYIN_METHOD_ORIGIN_TYPES } from './constants';
import { payinProviderCustomerIdParser } from '../payinProvider/parsers';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE } from '../origin/constants';
import { paypalPaymentMethodIdParser } from '../paypal/parsers';
import { paymentMethodCompositeKeyParamsParser, paymentMethodListLimitParser } from '../paymentMethod/parsers';

export const payinMethodOriginIdParser = stripePaymentMethodIdParser /*.or(paypal...)*/
  .refine((o) => {
    const r: PayinMethodOriginId = o; // assert
    return r;
  });

export const payinMethodOriginTypeParser = z.enum(PAYIN_METHOD_ORIGIN_TYPES);

export const payinMethodUpsertResultParser = payinProviderCustomerIdParser;

export const payinMethodListResultParser = z.array(
  z.discriminatedUnion('originType', [
    z.object({
      originType: z.literal(ORIGIN_TYPE_STRIPE),
      originId: stripePaymentMethodIdParser,
      originData: stripePaymentMethodFlatParser,
    }),
    z.object({
      originType: z.literal(ORIGIN_TYPE_PAYPAL),
      originId: paypalPaymentMethodIdParser,
    }),
  ])
);

export const payinMethodUpsertParamsParser = paymentMethodCompositeKeyParamsParser;
export const payinMethodDeleteParamsParser = paymentMethodCompositeKeyParamsParser; // no offset supported (stripe works on cursors also)
// userId is taken from auth
export const payinMethodListQueryParser = paymentMethodListLimitParser;
