import { compositeKeyParsers as parentCompositeKeyParsers } from '../../parsers.common';
import z from 'zod';
import { PayoutConversionProviderItemCompositeKey } from './types';
import { PayoutMethodOriginType } from '../../../payoutMethod/types';
import { omit } from '../../../utils/object';

export const compositeKeyParsers = {
  ...omit(parentCompositeKeyParsers, ['originType']),
  originTypeFrom: parentCompositeKeyParsers.originType,
  originTypeTo: parentCompositeKeyParsers.originType,
};
export const payoutConversionProviderItemCompositeKeyParser = z
  .object(compositeKeyParsers)
  .superRefine(({ originTypeFrom, originTypeTo }, ctx) => {
    if (originTypeFrom === originTypeTo) {
      ctx.addIssue({
        code: z.ZodIssueCode.custom,
        message: 'originTypeFrom and originTypeTo must be different',
      });
    }
  })
  .transform((r) => r as PayoutConversionProviderItemCompositeKey<PayoutMethodOriginType, PayoutMethodOriginType>);
