import z from 'zod';
import { ChannelType } from '../channel/types';
import { BLOG, COLLECTIVE, MIXSPACE } from '../channel/constants';
import { collectiveIdParser } from '../collective/parsers';
import { CollectiveId } from '../collective/types';
import { BlogId } from '../blog/id.types';
import { blogIdParser } from '../blog/parsers.id';

const splitParserCommons = z.object({
  activationThreshold: z.number().int().min(0).optional(),
  blogs: z.array(blogIdParser).default([] as BlogId[]),
  collectives: z.array(collectiveIdParser).default([] as CollectiveId[]),
});

export const makeSplitParser = {
  [BLOG]: splitParserCommons,
  [COLLECTIVE]: z
    .object({
      blogs: z.array(blogIdParser),
    })
    .merge(splitParserCommons),
  [MIXSPACE]: splitParserCommons,
} as const satisfies {
  [k in ChannelType]: any;
};

export type SplitParsed<T extends ChannelType> = z.infer<typeof makeSplitParser[T]>;
